# Python synthesizer [![Build Status](https://travis-ci.org/yuma-m/synthesizer.svg?branch=master)](https://travis-ci.org/yuma-m/synthesizer)

- Virtual analog synthesizer. 


## Author
- [Yuma Mihira](http://yurax2.com/)

## License

- GPL v3 License
